Freeze

Trait Freeze 

pub unsafe auto trait Freeze { }
๐Ÿ”ฌThis is a nightly-only experimental API. (freeze)
Used to determine whether a type contains any UnsafeCell internally, but not through an indirection. This affects, for example, whether a static of that type is placed in read-only static memory or writable static memory. This can be used to declare that a constant with a generic type will not contain interior mutability, and subsequently allow placing the constant behind references.

Safety

This trait is a core part of the language, it is just expressed as a trait in libcore for convenience. Do not implement it for other types.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> !Freeze for UnsafeCell<T>
where T: ?Sized,

Source

impl<T> Freeze for &T
where T: ?Sized,

Source

impl<T> Freeze for &mut T
where T: ?Sized,

Source

impl<T> Freeze for *const T is !null
where T: ?Sized,

Source

impl<T> Freeze for *const T
where T: ?Sized,

Source

impl<T> Freeze for *mut T is !null
where T: ?Sized,

Source

impl<T> Freeze for *mut T
where T: ?Sized,

1.28.0 ยท Source

impl<T> Freeze for NonZero<T>

Source

impl<T> Freeze for PhantomData<T>
where T: ?Sized,

Auto implementors



impl !Freeze for Barrier



impl !Freeze for sp_std::sync::nonpoison::Condvar



impl !Freeze for sp_std::sync::Condvar



impl !Freeze for sp_std::sync::Once



impl !Freeze for OnceState



impl Freeze for Abi



impl Freeze for sp_std::fmt::Alignment



impl Freeze for sp_std::mem::Alignment



impl Freeze for AllocError



impl Freeze for Array



impl Freeze for Assume



impl Freeze for BarrierWaitResult



impl Freeze for BorrowError



impl Freeze for BorrowMutError



impl Freeze for Const



impl Freeze for DebugAsHex



impl Freeze for DefaultHasher



impl Freeze for Duration



impl Freeze for DynTrait



impl Freeze for DynTraitPredicate



impl Freeze for Error



impl Freeze for FieldId



impl Freeze for FnPtr



impl Freeze for FormattingOptions



impl Freeze for FpCategory



impl Freeze for Generic



impl Freeze for GenericType



impl Freeze for GetDisjointMutError



impl Freeze for Global



impl Freeze for IntErrorKind



impl Freeze for Layout



impl Freeze for LayoutError



impl Freeze for Lifetime



impl Freeze for OneSidedRangeBound



impl Freeze for sp_std::cmp::Ordering



impl Freeze for sp_std::sync::atomic::Ordering



impl Freeze for ParseBoolError



impl Freeze for ParseFloatError



impl Freeze for ParseIntError



impl Freeze for PhantomPinned



impl Freeze for Pointer



impl Freeze for RandomState



impl Freeze for RangeFull



impl Freeze for RecvError



impl Freeze for sp_std::sync::mpmc::RecvTimeoutError



impl Freeze for Reference



impl Freeze for SearchStep



impl Freeze for Sign



impl Freeze for SipHasher



impl Freeze for Slice



impl Freeze for Str



impl Freeze for System



impl Freeze for Trait



impl Freeze for TryFromFloatSecsError



impl Freeze for TryFromIntError



impl Freeze for sp_std::sync::mpmc::TryRecvError



impl Freeze for Type



impl Freeze for TypeId



impl Freeze for TypeKind



impl Freeze for UnorderedKeyError



impl Freeze for Utf8Error



impl Freeze for VariantId



impl Freeze for WaitTimeoutResult



impl Freeze for WouldBlock



impl Freeze for Writer



impl<'a, 'b, const N: usize> Freeze for CharArrayRefSearcher<'a, 'b, N>
where <MultiCharEqPattern<&'b [char; N]> as Pattern>::Searcher<'a>: Freeze,



impl<'a, 'b> Freeze for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Freeze for DebugList<'a, 'b>



impl<'a, 'b> Freeze for DebugMap<'a, 'b>



impl<'a, 'b> Freeze for DebugSet<'a, 'b>



impl<'a, 'b> Freeze for DebugStruct<'a, 'b>



impl<'a, 'b> Freeze for DebugTuple<'a, 'b>



impl<'a, 'b> Freeze for StrSearcher<'a, 'b>



impl<'a, B> Freeze for Cow<'a, B>
where &'a B: Freeze, <B as ToOwned>::Owned: Freeze, B: ?Sized,



impl<'a, F> Freeze for CharPredicateSearcher<'a, F>
where <MultiCharEqPattern<F> as Pattern>::Searcher<'a>: Freeze,



impl<'a, I, A> Freeze for sp_std::collections::vec_deque::Splice<'a, I, A>
where Drain<'a, <I as Iterator>::Item, A>: Freeze, I: Freeze,



impl<'a, I, A> Freeze for sp_std::vec::Splice<'a, I, A>
where Drain<'a, <I as Iterator>::Item, A>: Freeze, I: Freeze,



impl<'a, I> Freeze for ByRefSized<'a, I>



impl<'a, K, A> Freeze for sp_std::collections::btree_set::CursorMut<'a, K, A>
where CursorMut<'a, K, SetValZST, A>: Freeze,



impl<'a, K, A> Freeze for sp_std::collections::btree_set::CursorMutKey<'a, K, A>
where CursorMutKey<'a, K, SetValZST, A>: Freeze,



impl<'a, K, V, A> Freeze for sp_std::collections::btree_map::CursorMut<'a, K, V, A>
where CursorMutKey<'a, K, V, A>: Freeze,



impl<'a, K, V, A> Freeze for sp_std::collections::btree_map::CursorMutKey<'a, K, V, A>
where Option<Handle<NodeRef<Mut<'a>, K, V, Leaf>, Edge>>: Freeze, DormantMutRef<'a, Option<NodeRef<Owned, K, V, LeafOrInternal>>>: Freeze, &'a mut A: Freeze,



impl<'a, K, V, A> Freeze for sp_std::collections::btree_map::Entry<'a, K, V, A>
where VacantEntry<'a, K, V, A>: Freeze, OccupiedEntry<'a, K, V, A>: Freeze,



impl<'a, K, V, A> Freeze for sp_std::collections::btree_map::OccupiedEntry<'a, K, V, A>
where Handle<NodeRef<Mut<'a>, K, V, LeafOrInternal>, KV>: Freeze, DormantMutRef<'a, BTreeMap<K, V, A>>: Freeze, A: Freeze, PhantomData<&'a mut (K, V)>: Freeze,



impl<'a, K, V, A> Freeze for OccupiedError<'a, K, V, A>
where OccupiedEntry<'a, K, V, A>: Freeze, K: Freeze, V: Freeze,



impl<'a, K, V, A> Freeze for sp_std::collections::btree_map::VacantEntry<'a, K, V, A>
where K: Freeze, Option<Handle<NodeRef<Mut<'a>, K, V, Leaf>, Edge>>: Freeze, DormantMutRef<'a, BTreeMap<K, V, A>>: Freeze, A: Freeze, PhantomData<&'a mut (K, V)>: Freeze,



impl<'a, K, V, R, F, A> Freeze for sp_std::collections::btree_map::ExtractIf<'a, K, V, R, F, A>
where F: Freeze, ExtractIfInner<'a, K, V, R>: Freeze, A: Freeze,



impl<'a, K, V> Freeze for sp_std::collections::btree_map::Cursor<'a, K, V>
where Option<Handle<NodeRef<Immut<'a>, K, V, Leaf>, Edge>>: Freeze, Option<&'a NodeRef<Owned, K, V, LeafOrInternal>>: Freeze,



impl<'a, K, V> Freeze for sp_std::collections::btree_map::Iter<'a, K, V>
where LazyLeafRange<Immut<'a>, K, V>: Freeze,



impl<'a, K, V> Freeze for sp_std::collections::btree_map::IterMut<'a, K, V>
where LazyLeafRange<ValMut<'a>, K, V>: Freeze, PhantomData<&'a mut (K, V)>: Freeze,



impl<'a, K, V> Freeze for Keys<'a, K, V>
where Iter<'a, K, V>: Freeze,



impl<'a, K, V> Freeze for sp_std::collections::btree_map::Range<'a, K, V>
where LeafRange<Immut<'a>, K, V>: Freeze,



impl<'a, K, V> Freeze for RangeMut<'a, K, V>
where LeafRange<ValMut<'a>, K, V>: Freeze, PhantomData<&'a mut (K, V)>: Freeze,



impl<'a, K, V> Freeze for Values<'a, K, V>
where Iter<'a, K, V>: Freeze,



impl<'a, K, V> Freeze for ValuesMut<'a, K, V>
where IterMut<'a, K, V>: Freeze,



impl<'a, K> Freeze for sp_std::collections::btree_set::Cursor<'a, K>
where Cursor<'a, K, SetValZST>: Freeze,



impl<'a, P> Freeze for MatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Freeze,



impl<'a, P> Freeze for Matches<'a, P>
where MatchesInternal<'a, P>: Freeze,



impl<'a, P> Freeze for RMatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Freeze,



impl<'a, P> Freeze for RMatches<'a, P>
where MatchesInternal<'a, P>: Freeze,



impl<'a, P> Freeze for sp_std::str::RSplit<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for sp_std::str::RSplitN<'a, P>
where SplitNInternal<'a, P>: Freeze,



impl<'a, P> Freeze for RSplitTerminator<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for sp_std::str::Split<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for sp_std::str::SplitInclusive<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for sp_std::str::SplitN<'a, P>
where SplitNInternal<'a, P>: Freeze,



impl<'a, P> Freeze for SplitTerminator<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, T, A> Freeze for Difference<'a, T, A>
where DifferenceInner<'a, T, A>: Freeze,



impl<'a, T, A> Freeze for sp_std::vec::Drain<'a, T, A>
where Iter<'a, T>: Freeze, NonNull<Vec<T, A>>: Freeze,



impl<'a, T, A> Freeze for sp_std::collections::vec_deque::Drain<'a, T, A>



impl<'a, T, A> Freeze for sp_std::collections::btree_set::Entry<'a, T, A>
where OccupiedEntry<'a, T, A>: Freeze, VacantEntry<'a, T, A>: Freeze,



impl<'a, T, A> Freeze for Intersection<'a, T, A>
where IntersectionInner<'a, T, A>: Freeze,



impl<'a, T, A> Freeze for sp_std::collections::btree_set::OccupiedEntry<'a, T, A>
where OccupiedEntry<'a, T, SetValZST, A>: Freeze,



impl<'a, T, A> Freeze for PeekMut<'a, T, A>
where &'a mut Vec<T, A>: Freeze,



impl<'a, T, A> Freeze for sp_std::collections::btree_set::VacantEntry<'a, T, A>
where VacantEntry<'a, T, SetValZST, A>: Freeze,



impl<'a, T, F, A> Freeze for sp_std::vec::ExtractIf<'a, T, F, A>
where &'a mut Vec<T, A>: Freeze, F: Freeze,



impl<'a, T, F, A> Freeze for sp_std::collections::vec_deque::ExtractIf<'a, T, F, A>
where &'a mut VecDeque<T, A>: Freeze, F: Freeze,



impl<'a, T, P> Freeze for ChunkBy<'a, T, P>
where &'a [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for ChunkByMut<'a, T, P>
where &'a mut [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for sp_std::slice::RSplit<'a, T, P>
where Split<'a, T, P>: Freeze,



impl<'a, T, P> Freeze for RSplitMut<'a, T, P>
where SplitMut<'a, T, P>: Freeze,



impl<'a, T, P> Freeze for sp_std::slice::RSplitN<'a, T, P>
where GenericSplitN<RSplit<'a, T, P>>: Freeze,



impl<'a, T, P> Freeze for RSplitNMut<'a, T, P>
where GenericSplitN<RSplitMut<'a, T, P>>: Freeze,



impl<'a, T, P> Freeze for sp_std::slice::Split<'a, T, P>
where &'a [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for sp_std::slice::SplitInclusive<'a, T, P>
where &'a [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for SplitInclusiveMut<'a, T, P>
where &'a mut [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for SplitMut<'a, T, P>
where &'a mut [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for sp_std::slice::SplitN<'a, T, P>
where GenericSplitN<Split<'a, T, P>>: Freeze,



impl<'a, T, P> Freeze for SplitNMut<'a, T, P>
where GenericSplitN<SplitMut<'a, T, P>>: Freeze,



impl<'a, T, R, F, A> Freeze for sp_std::collections::btree_set::ExtractIf<'a, T, R, F, A>
where F: Freeze, ExtractIfInner<'a, T, SetValZST, R>: Freeze, A: Freeze,



impl<'a, T, const N: usize> Freeze for ArrayWindows<'a, T, N>
where &'a [T]: Freeze,



impl<'a, T> Freeze for Chunks<'a, T>
where &'a [T]: Freeze,



impl<'a, T> Freeze for ChunksExact<'a, T>
where &'a [T]: Freeze,



impl<'a, T> Freeze for ChunksExactMut<'a, T>



impl<'a, T> Freeze for ChunksMut<'a, T>



impl<'a, T> Freeze for sp_std::sync::mpmc::Iter<'a, T>
where &'a Receiver<T>: Freeze,



impl<'a, T> Freeze for sp_std::sync::mpsc::Iter<'a, T>
where &'a Receiver<T>: Freeze,



impl<'a, T> Freeze for sp_std::collections::vec_deque::Iter<'a, T>
where Iter<'a, T>: Freeze,



impl<'a, T> Freeze for sp_std::collections::btree_set::Iter<'a, T>
where Keys<'a, T, SetValZST>: Freeze,



impl<'a, T> Freeze for sp_std::slice::Iter<'a, T>



impl<'a, T> Freeze for sp_std::result::Iter<'a, T>



impl<'a, T> Freeze for sp_std::collections::vec_deque::IterMut<'a, T>
where IterMut<'a, T>: Freeze,



impl<'a, T> Freeze for sp_std::slice::IterMut<'a, T>



impl<'a, T> Freeze for sp_std::result::IterMut<'a, T>



impl<'a, T> Freeze for sp_std::sync::nonpoison::MappedMutexGuard<'a, T>



impl<'a, T> Freeze for sp_std::sync::MappedMutexGuard<'a, T>



impl<'a, T> Freeze for sp_std::sync::nonpoison::MutexGuard<'a, T>
where &'a Mutex<T>: Freeze, T: ?Sized,



impl<'a, T> Freeze for sp_std::sync::MutexGuard<'a, T>
where &'a Mutex<T>: Freeze, T: ?Sized,



impl<'a, T> Freeze for RChunks<'a, T>
where &'a [T]: Freeze,



impl<'a, T> Freeze for RChunksExact<'a, T>
where &'a [T]: Freeze,



impl<'a, T> Freeze for RChunksExactMut<'a, T>
where *mut [T]: Freeze, &'a mut [T]: Freeze,



impl<'a, T> Freeze for RChunksMut<'a, T>



impl<'a, T> Freeze for sp_std::collections::btree_set::Range<'a, T>
where Range<'a, T, SetValZST>: Freeze,



impl<'a, T> Freeze for ReentrantLockGuard<'a, T>
where &'a ReentrantLock<T>: Freeze, T: ?Sized,



impl<'a, T> Freeze for SymmetricDifference<'a, T>
where MergeIterInner<Iter<'a, T>>: Freeze,



impl<'a, T> Freeze for sp_std::sync::mpmc::TryIter<'a, T>
where &'a Receiver<T>: Freeze,



impl<'a, T> Freeze for sp_std::sync::mpsc::TryIter<'a, T>
where &'a Receiver<T>: Freeze,



impl<'a, T> Freeze for Union<'a, T>
where MergeIterInner<Iter<'a, T>>: Freeze,



impl<'a, T> Freeze for Windows<'a, T>
where &'a [T]: Freeze,



impl<'a, const N: usize> Freeze for CharArraySearcher<'a, N>
where <MultiCharEqPattern<[char; N]> as Pattern>::Searcher<'a>: Freeze,



impl<'a> Freeze for Arguments<'a>



impl<'a> Freeze for Bytes<'a>



impl<'a> Freeze for CharIndices<'a>



impl<'a> Freeze for CharSearcher<'a>



impl<'a> Freeze for Chars<'a>



impl<'a> Freeze for EncodeUtf16<'a>



impl<'a> Freeze for EscapeAscii<'a>



impl<'a> Freeze for EscapeDebug<'a>



impl<'a> Freeze for EscapeDefault<'a>



impl<'a> Freeze for EscapeUnicode<'a>



impl<'a> Freeze for Formatter<'a>



impl<'a> Freeze for Lines<'a>



impl<'a> Freeze for LinesAny<'a>



impl<'a> Freeze for PhantomContravariantLifetime<'a>



impl<'a> Freeze for PhantomCovariantLifetime<'a>



impl<'a> Freeze for PhantomInvariantLifetime<'a>



impl<'a> Freeze for SplitAsciiWhitespace<'a>



impl<'a> Freeze for SplitWhitespace<'a>



impl<'a> Freeze for Utf8Chunk<'a>



impl<'a> Freeze for Utf8Chunks<'a>



impl<'a> Freeze for Utf8Pattern<'a>



impl<'b, T> Freeze for Ref<'b, T>
where NonNull<T>: Freeze, T: ?Sized,



impl<'b, T> Freeze for RefMut<'b, T>



impl<'rwlock, T> Freeze for sp_std::sync::nonpoison::MappedRwLockReadGuard<'rwlock, T>
where NonNull<T>: Freeze, T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::MappedRwLockReadGuard<'rwlock, T>
where NonNull<T>: Freeze, T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::nonpoison::MappedRwLockWriteGuard<'rwlock, T>



impl<'rwlock, T> Freeze for sp_std::sync::MappedRwLockWriteGuard<'rwlock, T>



impl<'rwlock, T> Freeze for sp_std::sync::nonpoison::RwLockReadGuard<'rwlock, T>
where NonNull<T>: Freeze, T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::RwLockReadGuard<'rwlock, T>
where NonNull<T>: Freeze, T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::nonpoison::RwLockWriteGuard<'rwlock, T>
where &'rwlock RwLock<T>: Freeze, T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::RwLockWriteGuard<'rwlock, T>
where &'rwlock RwLock<T>: Freeze, T: ?Sized,



impl<A, B> Freeze for Chain<A, B>
where Option<A>: Freeze, Option<B>: Freeze,



impl<A, B> Freeze for Zip<A, B>
where A: Freeze, B: Freeze,



impl<A> Freeze for Repeat<A>
where A: Freeze,



impl<A> Freeze for RepeatN<A>
where Option<RepeatNInner<A>>: Freeze,



impl<B, C> Freeze for ControlFlow<B, C>
where C: Freeze, B: Freeze,



impl<Dyn> Freeze for DynMetadata<Dyn>
where PhantomData<Dyn>: Freeze, Dyn: ?Sized,



impl<F> Freeze for sp_std::fmt::FromFn<F>
where F: Freeze,



impl<F> Freeze for sp_std::iter::FromFn<F>
where F: Freeze,



impl<F> Freeze for OnceWith<F>
where Option<F>: Freeze,



impl<F> Freeze for RepeatWith<F>
where F: Freeze,



impl<G> Freeze for FromCoroutine<G>
where G: Freeze,



impl<H> Freeze for BuildHasherDefault<H>
where PhantomData<fn() -> H>: Freeze,



impl<I, F, const N: usize> Freeze for MapWindows<I, F, N>
where F: Freeze, MapWindowsInner<I, N>: Freeze,



impl<I, F> Freeze for FilterMap<I, F>
where I: Freeze, F: Freeze,



impl<I, F> Freeze for Inspect<I, F>
where I: Freeze, F: Freeze,



impl<I, F> Freeze for Map<I, F>
where I: Freeze, F: Freeze,



impl<I, G> Freeze for IntersperseWith<I, G>
where G: Freeze, Option<<I as Iterator>::Item>: Freeze, I: Freeze,



impl<I, P> Freeze for Filter<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for MapWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for SkipWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for TakeWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, St, F> Freeze for Scan<I, St, F>
where I: Freeze, F: Freeze, St: Freeze,



impl<I, U, F> Freeze for FlatMap<I, U, F>
where FlattenCompat<Map<I, F>, <U as IntoIterator>::IntoIter>: Freeze,



impl<I, const N: usize> Freeze for ArrayChunks<I, N>
where I: Freeze, Option<IntoIter<<I as Iterator>::Item, N>>: Freeze,



impl<I> Freeze for Cloned<I>
where I: Freeze,



impl<I> Freeze for Copied<I>
where I: Freeze,



impl<I> Freeze for Cycle<I>
where I: Freeze,



impl<I> Freeze for Enumerate<I>
where I: Freeze,



impl<I> Freeze for Flatten<I>
where FlattenCompat<I, <<I as Iterator>::Item as IntoIterator>::IntoIter>: Freeze,



impl<I> Freeze for Fuse<I>
where Option<I>: Freeze,



impl<I> Freeze for Intersperse<I>
where <I as Iterator>::Item: Sized + Freeze, Option<<I as Iterator>::Item>: Freeze, I: Freeze,



impl<I> Freeze for Peekable<I>
where I: Freeze, Option<Option<<I as Iterator>::Item>>: Freeze,



impl<I> Freeze for Skip<I>
where I: Freeze,



impl<I> Freeze for StepBy<I>
where I: Freeze,



impl<I> Freeze for Take<I>
where I: Freeze,



impl<Idx> Freeze for sp_std::ops::Range<Idx>
where Idx: Freeze,



impl<Idx> Freeze for RangeFrom<Idx>
where Idx: Freeze,



impl<Idx> Freeze for RangeInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for RangeTo<Idx>
where Idx: Freeze,



impl<Idx> Freeze for RangeToInclusive<Idx>
where Idx: Freeze,



impl<K, V, A> Freeze for BTreeMap<K, V, A>
where Option<NodeRef<Owned, K, V, LeafOrInternal>>: Freeze, ManuallyDrop<A>: Freeze, PhantomData<Box<(K, V), A>>: Freeze,



impl<K, V, A> Freeze for sp_std::collections::btree_map::IntoIter<K, V, A>
where LazyLeafRange<Dying, K, V>: Freeze, A: Freeze,



impl<K, V, A> Freeze for IntoKeys<K, V, A>
where IntoIter<K, V, A>: Freeze,



impl<K, V, A> Freeze for IntoValues<K, V, A>
where IntoIter<K, V, A>: Freeze,



impl<P> Freeze for MaybeDangling<P>
where P: Freeze + ?Sized,



impl<T, A> Freeze for Arc<T, A>
where NonNull<ArcInner<T>>: Freeze, PhantomData<ArcInner<T>>: Freeze, A: Freeze, T: ?Sized,



impl<T, A> Freeze for BTreeSet<T, A>
where BTreeMap<T, SetValZST, A>: Freeze,



impl<T, A> Freeze for Box<T, A>
where Unique<T>: Freeze, A: Freeze, T: ?Sized,



impl<T, A> Freeze for sp_std::collections::btree_set::IntoIter<T, A>
where IntoIter<T, SetValZST, A>: Freeze,



impl<T, A> Freeze for sp_std::vec::IntoIter<T, A>



impl<T, A> Freeze for sp_std::collections::vec_deque::IntoIter<T, A>
where VecDeque<T, A>: Freeze,



impl<T, A> Freeze for Rc<T, A>
where NonNull<RcInner<T>>: Freeze, PhantomData<RcInner<T>>: Freeze, A: Freeze, T: ?Sized,



impl<T, A> Freeze for UniqueArc<T, A>
where NonNull<ArcInner<T>>: Freeze, PhantomData<ArcInner<T>>: Freeze, PhantomData<*mut T>: Freeze, A: Freeze, T: ?Sized,



impl<T, A> Freeze for UniqueRc<T, A>
where NonNull<RcInner<T>>: Freeze, PhantomData<RcInner<T>>: Freeze, PhantomData<*mut T>: Freeze, A: Freeze, T: ?Sized,



impl<T, A> Freeze for Vec<T, A>
where RawVec<T, A>: Freeze,



impl<T, A> Freeze for VecDeque<T, A>
where RawVec<T, A>: Freeze,



impl<T, A> Freeze for sp_std::sync::Weak<T, A>
where NonNull<ArcInner<T>>: Freeze, A: Freeze, T: ?Sized,



impl<T, A> Freeze for sp_std::rc::Weak<T, A>
where NonNull<RcInner<T>>: Freeze, A: Freeze, T: ?Sized,



impl<T, E> Freeze for Result<T, E>
where T: Freeze, E: Freeze,



impl<T, F = fn() -> T> !Freeze for LazyCell<T, F>



impl<T, F = fn() -> T> !Freeze for LazyLock<T, F>



impl<T, F> Freeze for DropGuard<T, F>



impl<T, F> Freeze for Successors<T, F>
where Option<T>: Freeze, F: Freeze,



impl<T, const N: usize, A> Freeze for BoxedArrayIntoIter<T, N, A>
where IntoIter<T, A>: Freeze,



impl<T> !Freeze for Atomic<T>



impl<T> !Freeze for Cell<T>



impl<T> !Freeze for CovariantUnsafeCell<T>



impl<T> !Freeze for sp_std::sync::nonpoison::Mutex<T>



impl<T> !Freeze for sp_std::sync::Mutex<T>



impl<T> !Freeze for OnceCell<T>



impl<T> !Freeze for OnceLock<T>



impl<T> !Freeze for ReentrantLock<T>



impl<T> !Freeze for RefCell<T>



impl<T> !Freeze for sp_std::sync::nonpoison::RwLock<T>



impl<T> !Freeze for sp_std::sync::RwLock<T>



impl<T> !Freeze for SyncUnsafeCell<T>



impl<T> Freeze for Bound<T>
where T: Freeze,



impl<T> Freeze for Complex<T>
where T: Freeze,



impl<T> Freeze for Discriminant<T>



impl<T> Freeze for Empty<T>
where PhantomData<fn() -> T>: Freeze,



impl<T> Freeze for sp_std::result::IntoIter<T>
where Option<T>: Freeze,



impl<T> Freeze for sp_std::sync::mpmc::IntoIter<T>
where Receiver<T>: Freeze,



impl<T> Freeze for sp_std::sync::mpsc::IntoIter<T>
where Receiver<T>: Freeze,



impl<T> Freeze for ManuallyDrop<T>
where MaybeDangling<T>: Freeze, T: ?Sized,



impl<T> Freeze for MaybeUninit<T>
where ManuallyDrop<T>: Freeze,



impl<T> Freeze for NonNull<T>
where *const T is !null: Freeze, T: ?Sized,



impl<T> Freeze for sp_std::iter::Once<T>
where IntoIter<T>: Freeze,



impl<T> Freeze for PhantomContravariant<T>
where PhantomData<fn(T)>: Freeze, T: ?Sized,



impl<T> Freeze for PhantomCovariant<T>
where PhantomData<fn() -> T>: Freeze, T: ?Sized,



impl<T> Freeze for PhantomInvariant<T>
where PhantomData<fn(T) -> T>: Freeze, T: ?Sized,



impl<T> Freeze for PoisonError<T>
where T: Freeze,



impl<T> Freeze for sp_std::sync::mpsc::Receiver<T>
where Receiver<T>: Freeze,



impl<T> Freeze for sp_std::sync::oneshot::Receiver<T>
where Receiver<T>: Freeze,



impl<T> Freeze for sp_std::sync::mpmc::Receiver<T>
where ReceiverFlavor<T>: Freeze,



impl<T> Freeze for sp_std::sync::oneshot::RecvTimeoutError<T>
where Receiver<T>: Freeze,



impl<T> Freeze for Rev<T>
where T: Freeze,



impl<T> Freeze for Reverse<T>
where T: Freeze,



impl<T> Freeze for Saturating<T>
where T: Freeze,



impl<T> Freeze for SendError<T>
where T: Freeze,



impl<T> Freeze for SendTimeoutError<T>
where T: Freeze,



impl<T> Freeze for sp_std::sync::mpsc::Sender<T>
where Sender<T>: Freeze,



impl<T> Freeze for sp_std::sync::oneshot::Sender<T>
where Sender<T>: Freeze,



impl<T> Freeze for sp_std::sync::mpmc::Sender<T>
where SenderFlavor<T>: Freeze,



impl<T> Freeze for SyncSender<T>
where Sender<T>: Freeze,



impl<T> Freeze for SyncView<T>
where T: Freeze + ?Sized,



impl<T> Freeze for ThinBox<T>
where PhantomData<T>: Freeze, T: ?Sized,



impl<T> Freeze for TraitImpl<T>
where DynMetadata<T>: Freeze, T: ?Sized,



impl<T> Freeze for TryLockError<T>
where PoisonError<T>: Freeze,



impl<T> Freeze for sp_std::sync::oneshot::TryRecvError<T>
where Receiver<T>: Freeze,



impl<T> Freeze for TrySendError<T>
where T: Freeze,



impl<T> Freeze for Wrapping<T>
where T: Freeze,



impl<T> Freeze for Yeet<T>
where T: Freeze,



impl<Y, R> Freeze for CoroutineState<Y, R>
where Y: Freeze, R: Freeze,