Sync

Trait Sync 

1.0.0 · Source
pub unsafe auto trait Sync { }
Types for which it is safe to share references between threads.

This trait is automatically implemented when the compiler determines it’s appropriate.

The precise definition is: a type T is Sync if and only if &T is Send. In other words, if there is no possibility of undefined behavior (including data races) when passing &T references between threads.

As one would expect, primitive types like u8 and f64 are all Sync, and so are simple aggregate types containing them, like tuples, structs and enums. More examples of basic Sync types include “immutable” types like &T, and those with simple inherited mutability, such as Box<T>, Vec<T> and most other collection types. (Generic parameters need to be Sync for their container to be Sync.)

A somewhat surprising consequence of the definition is that &mut T is Sync (if T is Sync) even though it seems like that might provide unsynchronized mutation. The trick is that a mutable reference behind a shared reference (that is, & &mut T) becomes read-only, as if it were a & &T. Hence there is no risk of a data race.

A shorter overview of how Sync and Send relate to referencing:

  • &T is Send if and only if T is Sync
  • &mut T is Send if and only if T is Send
  • &T and &mut T are Sync if and only if T is Sync

Types that are not Sync are those that have “interior mutability” in a non-thread-safe form, such as Cell and RefCell. These types allow for mutation of their contents even through an immutable, shared reference. For example the set method on Cell<T> takes &self, so it requires only a shared reference &Cell<T>. The method performs no synchronization, thus Cell cannot be Sync.

Another example of a non-Sync type is the reference-counting pointer Rc. Given any reference &Rc<T>, you can clone a new Rc<T>, modifying the reference counts in a non-atomic way.

For cases when one does need thread-safe interior mutability, Rust provides atomic data types, as well as explicit locking via sync::Mutex and sync::RwLock. These types ensure that any mutation cannot cause data races, hence the types are Sync. Likewise, sync::Arc provides a thread-safe analogue of Rc.

Any types with interior mutability must also use the cell::UnsafeCell wrapper around the value(s) which can be mutated through a shared reference. Failing to doing this is undefined behavior. For example, transmute-ing from &T to &mut T is invalid.

See the Nomicon for more details about Sync.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.26.0 · Source

impl !Sync for Args

1.26.0 · Source

impl !Sync for ArgsOs

1.0.0 · Source

impl !Sync for Arguments<'_>

Source

impl !Sync for LocalWaker

Source

impl Sync for core::ffi::c_str::Bytes<'_>

1.6.0 · Source

impl Sync for alloc::string::Drain<'_>

1.10.0 · Source

impl Sync for Location<'_>

1.0.0 · Source

impl Sync for TypeId

1.36.0 · Source

impl Sync for Waker

1.44.0 · Source

impl<'a> Sync for IoSlice<'a>

1.44.0 · Source

impl<'a> Sync for IoSliceMut<'a>

Source

impl<Dyn> Sync for DynMetadata<Dyn>
where Dyn: ?Sized,

1.0.0 · Source

impl<T, A> !Sync for Rc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> !Sync for UniqueRc<T, A>
where A: Allocator, T: ?Sized,

1.4.0 · Source

impl<T, A> !Sync for sp_std::rc::Weak<T, A>
where A: Allocator, T: ?Sized,

1.0.0 · Source

impl<T, A> Sync for Arc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Sync,

Source

impl<T, A> Sync for alloc::collections::linked_list::Cursor<'_, T, A>
where T: Sync, A: Allocator + Sync,

Source

impl<T, A> Sync for alloc::collections::linked_list::CursorMut<'_, T, A>
where T: Sync, A: Allocator + Sync,

1.6.0 · Source

impl<T, A> Sync for sp_std::collections::vec_deque::Drain<'_, T, A>
where T: Sync, A: Allocator + Sync,

1.6.0 · Source

impl<T, A> Sync for sp_std::vec::Drain<'_, T, A>
where T: Sync, A: Sync + Allocator,

1.0.0 · Source

impl<T, A> Sync for sp_std::vec::IntoIter<T, A>
where T: Sync, A: Allocator + Sync,

1.0.0 · Source

impl<T, A> Sync for LinkedList<T, A>
where T: Sync, A: Allocator + Sync,

Source

impl<T, A> Sync for UniqueArc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Sync,

1.4.0 · Source

impl<T, A> Sync for sp_std::sync::Weak<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Sync,

1.80.0 · Source

impl<T, F> Sync for LazyLock<T, F>
where T: Sync + Send, F: Send,

1.0.0 · Source

impl<T> !Sync for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> !Sync for *mut T
where T: ?Sized,

1.0.0 · Source

impl<T> !Sync for Cell<T>
where T: ?Sized,

1.25.0 · Source

impl<T> !Sync for NonNull<T>
where T: ?Sized,

NonNull pointers are not Sync because the data they reference may be aliased.

1.70.0 · Source

impl<T> !Sync for OnceCell<T>

1.0.0 · Source

impl<T> !Sync for sp_std::sync::mpsc::Receiver<T>

1.0.0 · Source

impl<T> !Sync for RefCell<T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Sync for UnsafeCell<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Sync for Atomic<T>
where T: AtomicPrimitive,

1.31.0 · Source

impl<T> Sync for ChunksExactMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for ChunksMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for sp_std::slice::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for alloc::collections::linked_list::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for sp_std::slice::IterMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for alloc::collections::linked_list::IterMut<'_, T>
where T: Sync,

1.29.0 · Source

impl<T> Sync for JoinHandle<T>

Source

impl<T> Sync for sp_std::sync::nonpoison::MappedMutexGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for sp_std::sync::MappedMutexGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for sp_std::sync::nonpoison::MappedRwLockReadGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for sp_std::sync::MappedRwLockReadGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for sp_std::sync::nonpoison::MappedRwLockWriteGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for sp_std::sync::MappedRwLockWriteGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for sp_std::sync::nonpoison::Mutex<T>
where T: Send + ?Sized,

T must be Send for Mutex to be Sync. This ensures that the protected data can be accessed safely from multiple threads without causing data races or other unsafe behavior.

Mutex<T> provides mutable access to T to one thread at a time. However, it’s essential for T to be Send because it’s not safe for non-Send structures to be accessed in this manner. For instance, consider Rc, a non-atomic reference counted smart pointer, which is not Send. With Rc, we can have multiple copies pointing to the same heap allocation with a non-atomic reference count. If we were to use Mutex<Rc<_>>, it would only protect one instance of Rc from shared access, leaving other copies vulnerable to potential data races.

Also note that it is not necessary for T to be Sync as &T is only made available to one thread at a time if T is not Sync.

1.0.0 · Source

impl<T> Sync for sp_std::sync::Mutex<T>
where T: Send + ?Sized,

T must be Send for Mutex to be Sync. This ensures that the protected data can be accessed safely from multiple threads without causing data races or other unsafe behavior.

Mutex<T> provides mutable access to T to one thread at a time. However, it’s essential for T to be Send because it’s not safe for non-Send structures to be accessed in this manner. For instance, consider Rc, a non-atomic reference counted smart pointer, which is not Send. With Rc, we can have multiple copies pointing to the same heap allocation with a non-atomic reference count. If we were to use Mutex<Rc<_>>, it would only protect one instance of Rc from shared access, leaving other copies vulnerable to potential data races.

Also note that it is not necessary for T to be Sync as &T is only made available to one thread at a time if T is not Sync.

Source

impl<T> Sync for sp_std::sync::nonpoison::MutexGuard<'_, T>
where T: Sync + ?Sized,

T must be Sync for a MutexGuard<T> to be Sync because it is possible to get a &T from &MutexGuard (via Deref).

1.19.0 · Source

impl<T> Sync for sp_std::sync::MutexGuard<'_, T>
where T: Sync + ?Sized,

T must be Sync for a MutexGuard<T> to be Sync because it is possible to get a &T from &MutexGuard (via Deref).

1.28.0 · Source

impl<T> Sync for NonZero<T>

1.70.0 · Source

impl<T> Sync for OnceLock<T>
where T: Sync + Send,

1.31.0 · Source

impl<T> Sync for RChunksExactMut<'_, T>
where T: Sync,

1.31.0 · Source

impl<T> Sync for RChunksMut<'_, T>
where T: Sync,

Source

impl<T> Sync for sp_std::sync::oneshot::Receiver<T>

Source

impl<T> Sync for sp_std::sync::mpmc::Receiver<T>
where T: Send,

Source

impl<T> Sync for ReentrantLock<T>
where T: Send + ?Sized,

Source

impl<T> Sync for ReentrantLockGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for sp_std::sync::nonpoison::RwLock<T>
where T: Send + Sync + ?Sized,

1.0.0 · Source

impl<T> Sync for sp_std::sync::RwLock<T>
where T: Send + Sync + ?Sized,

Source

impl<T> Sync for sp_std::sync::nonpoison::RwLockReadGuard<'_, T>
where T: Sync + ?Sized,

1.23.0 · Source

impl<T> Sync for sp_std::sync::RwLockReadGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for sp_std::sync::nonpoison::RwLockWriteGuard<'_, T>
where T: Sync + ?Sized,

1.23.0 · Source

impl<T> Sync for sp_std::sync::RwLockWriteGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Sync for sp_std::sync::oneshot::Sender<T>

Source

impl<T> Sync for sp_std::sync::mpmc::Sender<T>
where T: Send,

1.72.0 · Source

impl<T> Sync for sp_std::sync::mpsc::Sender<T>
where T: Send,

Source

impl<T> Sync for SyncUnsafeCell<T>
where T: Sync + ?Sized,

Source

impl<T> Sync for SyncView<T>
where T: ?Sized,

Source

impl<T> Sync for ThinBox<T>
where T: Sync + ?Sized,

ThinBox<T> is Sync if T is Sync because the data is owned.

Source

impl<T> Sync for UnsafePinned<T>
where T: Sync + ?Sized,

Auto implementors



impl !Sync for OnceState



impl Sync for Abi



impl Sync for sp_std::fmt::Alignment



impl Sync for sp_std::mem::Alignment



impl Sync for AllocError



impl Sync for Array



impl Sync for Assume



impl Sync for Barrier



impl Sync for BarrierWaitResult



impl Sync for Bool



impl Sync for BorrowError



impl Sync for BorrowMutError



impl Sync for Char



impl Sync for sp_std::sync::nonpoison::Condvar



impl Sync for sp_std::sync::Condvar



impl Sync for Const



impl Sync for DebugAsHex



impl Sync for DefaultHasher



impl Sync for Duration



impl Sync for DynTrait



impl Sync for DynTraitPredicate



impl Sync for Enum



impl Sync for Error



impl Sync for Field



impl Sync for FieldId



impl Sync for Float



impl Sync for FnPtr



impl Sync for FormattingOptions



impl Sync for FpCategory



impl Sync for Generic



impl Sync for GenericType



impl Sync for GetDisjointMutError



impl Sync for Global



impl Sync for Infallible



impl Sync for Int



impl Sync for IntErrorKind



impl Sync for Layout



impl Sync for LayoutError



impl Sync for Lifetime



impl Sync for sp_std::sync::Once



impl Sync for OneSidedRangeBound



impl Sync for sp_std::cmp::Ordering



impl Sync for sp_std::sync::atomic::Ordering



impl Sync for ParseBoolError



impl Sync for ParseFloatError



impl Sync for ParseIntError



impl Sync for PhantomPinned



impl Sync for Pointer



impl Sync for RandomState



impl Sync for RangeFull



impl Sync for RecvError



impl Sync for sp_std::sync::mpmc::RecvTimeoutError



impl Sync for Reference



impl Sync for SearchStep



impl Sync for Sign



impl Sync for SipHasher



impl Sync for Slice



impl Sync for Str



impl Sync for Struct



impl Sync for System



impl Sync for Trait



impl Sync for TryFromFloatSecsError



impl Sync for TryFromIntError



impl Sync for sp_std::sync::mpmc::TryRecvError



impl Sync for Tuple



impl Sync for Type



impl Sync for TypeKind



impl Sync for sp_std::mem::type_info::Union



impl Sync for UnorderedKeyError



impl Sync for Utf8Error



impl Sync for Variant



impl Sync for WaitTimeoutResult



impl Sync for WouldBlock



impl Sync for Writer



impl<'a, 'b, const N: usize> Sync for CharArrayRefSearcher<'a, 'b, N>



impl<'a, 'b> !Sync for DebugList<'a, 'b>



impl<'a, 'b> !Sync for DebugMap<'a, 'b>



impl<'a, 'b> !Sync for DebugSet<'a, 'b>



impl<'a, 'b> !Sync for DebugStruct<'a, 'b>



impl<'a, 'b> !Sync for DebugTuple<'a, 'b>



impl<'a, 'b> Sync for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Sync for StrSearcher<'a, 'b>



impl<'a, B> Sync for Cow<'a, B>
where <B as ToOwned>::Owned: Sync, B: Sync + ?Sized,



impl<'a, F> Sync for CharPredicateSearcher<'a, F>
where F: Sync,



impl<'a, I, A> Sync for sp_std::collections::vec_deque::Splice<'a, I, A>
where I: Sync, <I as Iterator>::Item: Sync, A: Sync,



impl<'a, I, A> Sync for sp_std::vec::Splice<'a, I, A>
where I: Sync, <I as Iterator>::Item: Sync, A: Sync,



impl<'a, I> Sync for ByRefSized<'a, I>
where I: Sync,



impl<'a, K, A> Sync for sp_std::collections::btree_set::CursorMut<'a, K, A>
where A: Sync, K: Sync,



impl<'a, K, A> Sync for sp_std::collections::btree_set::CursorMutKey<'a, K, A>
where A: Sync, K: Sync,



impl<'a, K, V, A> Sync for sp_std::collections::btree_map::CursorMut<'a, K, V, A>
where A: Sync, K: Sync, V: Sync,



impl<'a, K, V, A> Sync for sp_std::collections::btree_map::CursorMutKey<'a, K, V, A>
where A: Sync, K: Sync, V: Sync,



impl<'a, K, V, A> Sync for sp_std::collections::btree_map::Entry<'a, K, V, A>
where K: Sync, A: Sync, V: Sync,



impl<'a, K, V, A> Sync for sp_std::collections::btree_map::OccupiedEntry<'a, K, V, A>
where A: Sync, K: Sync, V: Sync,



impl<'a, K, V, A> Sync for OccupiedError<'a, K, V, A>
where K: Sync, V: Sync, A: Sync,



impl<'a, K, V, A> Sync for sp_std::collections::btree_map::VacantEntry<'a, K, V, A>
where K: Sync, A: Sync, V: Sync,



impl<'a, K, V, R, F, A> Sync for sp_std::collections::btree_map::ExtractIf<'a, K, V, R, F, A>
where F: Sync, A: Sync, R: Sync, K: Sync, V: Sync,



impl<'a, K, V> Sync for sp_std::collections::btree_map::Cursor<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for sp_std::collections::btree_map::Iter<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for sp_std::collections::btree_map::IterMut<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for Keys<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for sp_std::collections::btree_map::Range<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for RangeMut<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for Values<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Sync for ValuesMut<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K> Sync for sp_std::collections::btree_set::Cursor<'a, K>
where K: Sync,



impl<'a, P> Sync for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for sp_std::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for sp_std::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for sp_std::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for sp_std::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for sp_std::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, T, A> Sync for Difference<'a, T, A>
where T: Sync, A: Sync,



impl<'a, T, A> Sync for sp_std::collections::btree_set::Entry<'a, T, A>
where A: Sync, T: Sync,



impl<'a, T, A> Sync for Intersection<'a, T, A>
where T: Sync, A: Sync,



impl<'a, T, A> Sync for sp_std::collections::btree_set::OccupiedEntry<'a, T, A>
where A: Sync, T: Sync,



impl<'a, T, A> Sync for PeekMut<'a, T, A>
where A: Sync, T: Sync,



impl<'a, T, A> Sync for sp_std::collections::btree_set::VacantEntry<'a, T, A>
where T: Sync, A: Sync,



impl<'a, T, F, A> Sync for sp_std::collections::vec_deque::ExtractIf<'a, T, F, A>
where F: Sync, A: Sync, T: Sync,



impl<'a, T, F, A> Sync for sp_std::vec::ExtractIf<'a, T, F, A>
where F: Sync, A: Sync, T: Sync,



impl<'a, T, P> Sync for ChunkBy<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for ChunkByMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for sp_std::slice::RSplit<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for RSplitMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for sp_std::slice::RSplitN<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for RSplitNMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for sp_std::slice::Split<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for sp_std::slice::SplitInclusive<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitInclusiveMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for sp_std::slice::SplitN<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitNMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, R, F, A> Sync for sp_std::collections::btree_set::ExtractIf<'a, T, R, F, A>
where F: Sync, A: Sync, R: Sync, T: Sync,



impl<'a, T, const N: usize> Sync for ArrayWindows<'a, T, N>
where T: Sync,



impl<'a, T> !Sync for sp_std::sync::mpsc::Iter<'a, T>



impl<'a, T> !Sync for sp_std::sync::mpsc::TryIter<'a, T>



impl<'a, T> Sync for Chunks<'a, T>
where T: Sync,



impl<'a, T> Sync for ChunksExact<'a, T>
where T: Sync,



impl<'a, T> Sync for sp_std::sync::mpmc::Iter<'a, T>
where T: Send,



impl<'a, T> Sync for sp_std::collections::btree_set::Iter<'a, T>
where T: Sync,



impl<'a, T> Sync for sp_std::collections::vec_deque::Iter<'a, T>
where T: Sync,



impl<'a, T> Sync for sp_std::result::Iter<'a, T>
where T: Sync,



impl<'a, T> Sync for sp_std::collections::vec_deque::IterMut<'a, T>
where T: Sync,



impl<'a, T> Sync for sp_std::result::IterMut<'a, T>
where T: Sync,



impl<'a, T> Sync for RChunks<'a, T>
where T: Sync,



impl<'a, T> Sync for RChunksExact<'a, T>
where T: Sync,



impl<'a, T> Sync for sp_std::collections::btree_set::Range<'a, T>
where T: Sync,



impl<'a, T> Sync for SymmetricDifference<'a, T>
where T: Sync,



impl<'a, T> Sync for sp_std::sync::mpmc::TryIter<'a, T>
where T: Send,



impl<'a, T> Sync for sp_std::collections::btree_set::Union<'a, T>
where T: Sync,



impl<'a, T> Sync for Windows<'a, T>
where T: Sync,



impl<'a, const N: usize> Sync for CharArraySearcher<'a, N>



impl<'a> !Sync for Formatter<'a>



impl<'a> Sync for sp_std::str::Bytes<'a>



impl<'a> Sync for CharIndices<'a>



impl<'a> Sync for CharSearcher<'a>



impl<'a> Sync for Chars<'a>



impl<'a> Sync for EncodeUtf16<'a>



impl<'a> Sync for EscapeAscii<'a>



impl<'a> Sync for EscapeDebug<'a>



impl<'a> Sync for EscapeDefault<'a>



impl<'a> Sync for EscapeUnicode<'a>



impl<'a> Sync for Lines<'a>



impl<'a> Sync for LinesAny<'a>



impl<'a> Sync for PhantomContravariantLifetime<'a>



impl<'a> Sync for PhantomCovariantLifetime<'a>



impl<'a> Sync for PhantomInvariantLifetime<'a>



impl<'a> Sync for SplitAsciiWhitespace<'a>



impl<'a> Sync for SplitWhitespace<'a>



impl<'a> Sync for Utf8Chunk<'a>



impl<'a> Sync for Utf8Chunks<'a>



impl<'a> Sync for Utf8Pattern<'a>



impl<'b, T> !Sync for Ref<'b, T>



impl<'b, T> !Sync for RefMut<'b, T>



impl<A, B> Sync for Chain<A, B>
where A: Sync, B: Sync,



impl<A, B> Sync for Zip<A, B>
where A: Sync, B: Sync,



impl<A> Sync for Repeat<A>
where A: Sync,



impl<A> Sync for RepeatN<A>
where A: Sync,



impl<B, C> Sync for ControlFlow<B, C>
where C: Sync, B: Sync,



impl<F> Sync for sp_std::fmt::FromFn<F>
where F: Sync,



impl<F> Sync for sp_std::iter::FromFn<F>
where F: Sync,



impl<F> Sync for OnceWith<F>
where F: Sync,



impl<F> Sync for RepeatWith<F>
where F: Sync,



impl<G> Sync for FromCoroutine<G>
where G: Sync,



impl<H> Sync for BuildHasherDefault<H>



impl<I, F, const N: usize> Sync for MapWindows<I, F, N>
where F: Sync, I: Sync, <I as Iterator>::Item: Sync,



impl<I, F> Sync for FilterMap<I, F>
where I: Sync, F: Sync,



impl<I, F> Sync for Inspect<I, F>
where I: Sync, F: Sync,



impl<I, F> Sync for Map<I, F>
where I: Sync, F: Sync,



impl<I, G> Sync for IntersperseWith<I, G>
where G: Sync, I: Sync, <I as Iterator>::Item: Sync,



impl<I, P> Sync for Filter<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for MapWhile<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for SkipWhile<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for TakeWhile<I, P>
where I: Sync, P: Sync,



impl<I, St, F> Sync for Scan<I, St, F>
where I: Sync, F: Sync, St: Sync,



impl<I, U, F> Sync for FlatMap<I, U, F>
where <U as IntoIterator>::IntoIter: Sync, I: Sync, F: Sync,



impl<I, const N: usize> Sync for ArrayChunks<I, N>
where I: Sync, <I as Iterator>::Item: Sync,



impl<I> Sync for Cloned<I>
where I: Sync,



impl<I> Sync for Copied<I>
where I: Sync,



impl<I> Sync for Cycle<I>
where I: Sync,



impl<I> Sync for Enumerate<I>
where I: Sync,



impl<I> Sync for Flatten<I>
where <<I as Iterator>::Item as IntoIterator>::IntoIter: Sync, I: Sync,



impl<I> Sync for Fuse<I>
where I: Sync,



impl<I> Sync for Intersperse<I>
where <I as Iterator>::Item: Sized + Sync, I: Sync,



impl<I> Sync for Peekable<I>
where I: Sync, <I as Iterator>::Item: Sync,



impl<I> Sync for Skip<I>
where I: Sync,



impl<I> Sync for StepBy<I>
where I: Sync,



impl<I> Sync for Take<I>
where I: Sync,



impl<Idx> Sync for sp_std::ops::Range<Idx>
where Idx: Sync,



impl<Idx> Sync for RangeFrom<Idx>
where Idx: Sync,



impl<Idx> Sync for RangeInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for RangeTo<Idx>
where Idx: Sync,



impl<Idx> Sync for RangeToInclusive<Idx>
where Idx: Sync,



impl<K, V, A> Sync for BTreeMap<K, V, A>
where K: Sync, V: Sync, A: Sync,



impl<K, V, A> Sync for sp_std::collections::btree_map::IntoIter<K, V, A>
where A: Sync, K: Sync, V: Sync,



impl<K, V, A> Sync for IntoKeys<K, V, A>
where A: Sync, K: Sync, V: Sync,



impl<K, V, A> Sync for IntoValues<K, V, A>
where A: Sync, K: Sync, V: Sync,



impl<P> Sync for MaybeDangling<P>
where P: Sync + ?Sized,



impl<T, A> Sync for BTreeSet<T, A>
where T: Sync, A: Sync,



impl<T, A> Sync for Box<T, A>
where A: Sync, T: Sync + ?Sized,



impl<T, A> Sync for sp_std::collections::btree_set::IntoIter<T, A>
where A: Sync, T: Sync,



impl<T, A> Sync for sp_std::collections::vec_deque::IntoIter<T, A>
where A: Sync, T: Sync,



impl<T, A> Sync for Vec<T, A>
where A: Sync, T: Sync,



impl<T, A> Sync for VecDeque<T, A>
where A: Sync, T: Sync,



impl<T, E> Sync for Result<T, E>
where T: Sync, E: Sync,



impl<T, F = fn() -> T> !Sync for LazyCell<T, F>



impl<T, F> Sync for DropGuard<T, F>
where T: Sync, F: Sync,



impl<T, F> Sync for Successors<T, F>
where F: Sync, T: Sync,



impl<T> !Sync for sp_std::sync::mpsc::IntoIter<T>



impl<T> Sync for Bound<T>
where T: Sync,



impl<T> Sync for Discriminant<T>



impl<T> Sync for Empty<T>



impl<T> Sync for sp_std::sync::mpmc::IntoIter<T>
where T: Send,



impl<T> Sync for sp_std::result::IntoIter<T>
where T: Sync,



impl<T> Sync for ManuallyDrop<T>
where T: Sync + ?Sized,



impl<T> Sync for MaybeUninit<T>
where T: Sync,



impl<T> Sync for sp_std::iter::Once<T>
where T: Sync,



impl<T> Sync for PhantomContravariant<T>
where T: ?Sized,



impl<T> Sync for PhantomCovariant<T>
where T: ?Sized,



impl<T> Sync for PhantomData<T>
where T: Sync + ?Sized,



impl<T> Sync for PhantomInvariant<T>
where T: ?Sized,



impl<T> Sync for PoisonError<T>
where T: Sync,



impl<T> Sync for sp_std::sync::oneshot::RecvTimeoutError<T>



impl<T> Sync for Rev<T>
where T: Sync,



impl<T> Sync for Reverse<T>
where T: Sync,



impl<T> Sync for Saturating<T>
where T: Sync,



impl<T> Sync for SendError<T>
where T: Sync,



impl<T> Sync for SendTimeoutError<T>
where T: Sync,



impl<T> Sync for SyncSender<T>
where T: Send,



impl<T> Sync for TraitImpl<T>
where T: ?Sized,



impl<T> Sync for TryLockError<T>
where T: Sync,



impl<T> Sync for sp_std::sync::oneshot::TryRecvError<T>



impl<T> Sync for TrySendError<T>
where T: Sync,



impl<T> Sync for Wrapping<T>
where T: Sync,



impl<T> Sync for Yeet<T>
where T: Sync,



impl<Y, R> Sync for CoroutineState<Y, R>
where Y: Sync, R: Sync,