Freeze

Trait Freeze 

pub unsafe auto trait Freeze { }
๐Ÿ”ฌThis is a nightly-only experimental API. (freeze)
Used to determine whether a type contains any UnsafeCell internally, but not through an indirection. This affects, for example, whether a static of that type is placed in read-only static memory or writable static memory. This can be used to declare that a constant with a generic type will not contain interior mutability, and subsequently allow placing the constant behind references.

Safety

This trait is a core part of the language, it is just expressed as a trait in libcore for convenience. Do not implement it for other types.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> !Freeze for UnsafeCell<T>
where T: ?Sized,

Source

impl<T> Freeze for &T
where T: ?Sized,

Source

impl<T> Freeze for &mut T
where T: ?Sized,

Source

impl<T> Freeze for *const T is !null
where T: ?Sized,

Source

impl<T> Freeze for *const T
where T: ?Sized,

Source

impl<T> Freeze for *mut T is !null
where T: ?Sized,

Source

impl<T> Freeze for *mut T
where T: ?Sized,

1.28.0 ยท Source

impl<T> Freeze for NonZero<T>

Source

impl<T> Freeze for PhantomData<T>
where T: ?Sized,

Auto implementors



impl !Freeze for Barrier



impl !Freeze for sp_std::sync::nonpoison::Condvar



impl !Freeze for sp_std::sync::Condvar



impl !Freeze for sp_std::sync::Once



impl !Freeze for OnceState



impl Freeze for Abi



impl Freeze for sp_std::fmt::Alignment



impl Freeze for sp_std::mem::Alignment



impl Freeze for AllocError



impl Freeze for Array



impl Freeze for Assume



impl Freeze for BarrierWaitResult



impl Freeze for Bool



impl Freeze for BorrowError



impl Freeze for BorrowMutError



impl Freeze for Char



impl Freeze for Const



impl Freeze for DebugAsHex



impl Freeze for DefaultHasher



impl Freeze for Duration



impl Freeze for DynTrait



impl Freeze for DynTraitPredicate



impl Freeze for Enum



impl Freeze for Error



impl Freeze for Field



impl Freeze for FieldId



impl Freeze for Float



impl Freeze for FnPtr



impl Freeze for FormattingOptions



impl Freeze for FpCategory



impl Freeze for Generic



impl Freeze for GenericType



impl Freeze for GetDisjointMutError



impl Freeze for Global



impl Freeze for Infallible



impl Freeze for Int



impl Freeze for IntErrorKind



impl Freeze for Layout



impl Freeze for LayoutError



impl Freeze for Lifetime



impl Freeze for OneSidedRangeBound



impl Freeze for sp_std::cmp::Ordering



impl Freeze for sp_std::sync::atomic::Ordering



impl Freeze for ParseBoolError



impl Freeze for ParseFloatError



impl Freeze for ParseIntError



impl Freeze for PhantomPinned



impl Freeze for Pointer



impl Freeze for RandomState



impl Freeze for RangeFull



impl Freeze for RecvError



impl Freeze for sp_std::sync::mpmc::RecvTimeoutError



impl Freeze for Reference



impl Freeze for SearchStep



impl Freeze for Sign



impl Freeze for SipHasher



impl Freeze for Slice



impl Freeze for Str



impl Freeze for Struct



impl Freeze for System



impl Freeze for Trait



impl Freeze for TryFromFloatSecsError



impl Freeze for TryFromIntError



impl Freeze for sp_std::sync::mpmc::TryRecvError



impl Freeze for Tuple



impl Freeze for Type



impl Freeze for TypeId



impl Freeze for TypeKind



impl Freeze for sp_std::mem::type_info::Union



impl Freeze for UnorderedKeyError



impl Freeze for Utf8Error



impl Freeze for Variant



impl Freeze for WaitTimeoutResult



impl Freeze for WouldBlock



impl Freeze for Writer



impl<'a, 'b, const N: usize> Freeze for CharArrayRefSearcher<'a, 'b, N>



impl<'a, 'b> Freeze for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Freeze for DebugList<'a, 'b>



impl<'a, 'b> Freeze for DebugMap<'a, 'b>



impl<'a, 'b> Freeze for DebugSet<'a, 'b>



impl<'a, 'b> Freeze for DebugStruct<'a, 'b>



impl<'a, 'b> Freeze for DebugTuple<'a, 'b>



impl<'a, 'b> Freeze for StrSearcher<'a, 'b>



impl<'a, B> Freeze for Cow<'a, B>
where <B as ToOwned>::Owned: Freeze, B: ?Sized,



impl<'a, F> Freeze for CharPredicateSearcher<'a, F>
where F: Freeze,



impl<'a, I, A> Freeze for sp_std::collections::vec_deque::Splice<'a, I, A>
where I: Freeze,



impl<'a, I, A> Freeze for sp_std::vec::Splice<'a, I, A>
where I: Freeze,



impl<'a, I> Freeze for ByRefSized<'a, I>



impl<'a, K, A> Freeze for sp_std::collections::btree_set::CursorMut<'a, K, A>



impl<'a, K, A> Freeze for sp_std::collections::btree_set::CursorMutKey<'a, K, A>



impl<'a, K, V, A> Freeze for sp_std::collections::btree_map::CursorMut<'a, K, V, A>



impl<'a, K, V, A> Freeze for sp_std::collections::btree_map::CursorMutKey<'a, K, V, A>



impl<'a, K, V, A> Freeze for sp_std::collections::btree_map::Entry<'a, K, V, A>
where K: Freeze, A: Freeze,



impl<'a, K, V, A> Freeze for sp_std::collections::btree_map::OccupiedEntry<'a, K, V, A>
where A: Freeze,



impl<'a, K, V, A> Freeze for OccupiedError<'a, K, V, A>
where K: Freeze, V: Freeze, A: Freeze,



impl<'a, K, V, A> Freeze for sp_std::collections::btree_map::VacantEntry<'a, K, V, A>
where K: Freeze, A: Freeze,



impl<'a, K, V, R, F, A> Freeze for sp_std::collections::btree_map::ExtractIf<'a, K, V, R, F, A>
where F: Freeze, A: Freeze, R: Freeze,



impl<'a, K, V> Freeze for sp_std::collections::btree_map::Cursor<'a, K, V>



impl<'a, K, V> Freeze for sp_std::collections::btree_map::Iter<'a, K, V>



impl<'a, K, V> Freeze for sp_std::collections::btree_map::IterMut<'a, K, V>



impl<'a, K, V> Freeze for Keys<'a, K, V>



impl<'a, K, V> Freeze for sp_std::collections::btree_map::Range<'a, K, V>



impl<'a, K, V> Freeze for RangeMut<'a, K, V>



impl<'a, K, V> Freeze for Values<'a, K, V>



impl<'a, K, V> Freeze for ValuesMut<'a, K, V>



impl<'a, K> Freeze for sp_std::collections::btree_set::Cursor<'a, K>



impl<'a, P> Freeze for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for sp_std::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for sp_std::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for sp_std::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for sp_std::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for sp_std::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, T, A> Freeze for Difference<'a, T, A>



impl<'a, T, A> Freeze for sp_std::collections::vec_deque::Drain<'a, T, A>



impl<'a, T, A> Freeze for sp_std::vec::Drain<'a, T, A>



impl<'a, T, A> Freeze for sp_std::collections::btree_set::Entry<'a, T, A>
where A: Freeze, T: Freeze,



impl<'a, T, A> Freeze for Intersection<'a, T, A>



impl<'a, T, A> Freeze for sp_std::collections::btree_set::OccupiedEntry<'a, T, A>
where A: Freeze,



impl<'a, T, A> Freeze for PeekMut<'a, T, A>



impl<'a, T, A> Freeze for sp_std::collections::btree_set::VacantEntry<'a, T, A>
where T: Freeze, A: Freeze,



impl<'a, T, F, A> Freeze for sp_std::collections::vec_deque::ExtractIf<'a, T, F, A>
where F: Freeze,



impl<'a, T, F, A> Freeze for sp_std::vec::ExtractIf<'a, T, F, A>
where F: Freeze,



impl<'a, T, P> Freeze for ChunkBy<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for ChunkByMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for sp_std::slice::RSplit<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for RSplitMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for sp_std::slice::RSplitN<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for RSplitNMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for sp_std::slice::Split<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for sp_std::slice::SplitInclusive<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for SplitInclusiveMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for SplitMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for sp_std::slice::SplitN<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for SplitNMut<'a, T, P>
where P: Freeze,



impl<'a, T, R, F, A> Freeze for sp_std::collections::btree_set::ExtractIf<'a, T, R, F, A>
where F: Freeze, A: Freeze, R: Freeze,



impl<'a, T, const N: usize> Freeze for ArrayWindows<'a, T, N>



impl<'a, T> Freeze for Chunks<'a, T>



impl<'a, T> Freeze for ChunksExact<'a, T>



impl<'a, T> Freeze for ChunksExactMut<'a, T>



impl<'a, T> Freeze for ChunksMut<'a, T>



impl<'a, T> Freeze for sp_std::collections::btree_set::Iter<'a, T>



impl<'a, T> Freeze for sp_std::collections::vec_deque::Iter<'a, T>



impl<'a, T> Freeze for sp_std::sync::mpmc::Iter<'a, T>



impl<'a, T> Freeze for sp_std::sync::mpsc::Iter<'a, T>



impl<'a, T> Freeze for sp_std::result::Iter<'a, T>



impl<'a, T> Freeze for sp_std::slice::Iter<'a, T>



impl<'a, T> Freeze for sp_std::collections::vec_deque::IterMut<'a, T>



impl<'a, T> Freeze for sp_std::result::IterMut<'a, T>



impl<'a, T> Freeze for sp_std::slice::IterMut<'a, T>



impl<'a, T> Freeze for sp_std::sync::nonpoison::MappedMutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for sp_std::sync::MappedMutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for sp_std::sync::nonpoison::MutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for sp_std::sync::MutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for RChunks<'a, T>



impl<'a, T> Freeze for RChunksExact<'a, T>



impl<'a, T> Freeze for RChunksExactMut<'a, T>



impl<'a, T> Freeze for RChunksMut<'a, T>



impl<'a, T> Freeze for sp_std::collections::btree_set::Range<'a, T>



impl<'a, T> Freeze for ReentrantLockGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for SymmetricDifference<'a, T>



impl<'a, T> Freeze for sp_std::sync::mpmc::TryIter<'a, T>



impl<'a, T> Freeze for sp_std::sync::mpsc::TryIter<'a, T>



impl<'a, T> Freeze for sp_std::collections::btree_set::Union<'a, T>



impl<'a, T> Freeze for Windows<'a, T>



impl<'a, const N: usize> Freeze for CharArraySearcher<'a, N>



impl<'a> Freeze for Arguments<'a>



impl<'a> Freeze for Bytes<'a>



impl<'a> Freeze for CharIndices<'a>



impl<'a> Freeze for CharSearcher<'a>



impl<'a> Freeze for Chars<'a>



impl<'a> Freeze for EncodeUtf16<'a>



impl<'a> Freeze for EscapeAscii<'a>



impl<'a> Freeze for EscapeDebug<'a>



impl<'a> Freeze for EscapeDefault<'a>



impl<'a> Freeze for EscapeUnicode<'a>



impl<'a> Freeze for Formatter<'a>



impl<'a> Freeze for Lines<'a>



impl<'a> Freeze for LinesAny<'a>



impl<'a> Freeze for PhantomContravariantLifetime<'a>



impl<'a> Freeze for PhantomCovariantLifetime<'a>



impl<'a> Freeze for PhantomInvariantLifetime<'a>



impl<'a> Freeze for SplitAsciiWhitespace<'a>



impl<'a> Freeze for SplitWhitespace<'a>



impl<'a> Freeze for Utf8Chunk<'a>



impl<'a> Freeze for Utf8Chunks<'a>



impl<'a> Freeze for Utf8Pattern<'a>



impl<'b, T> Freeze for Ref<'b, T>
where T: ?Sized,



impl<'b, T> Freeze for RefMut<'b, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::nonpoison::MappedRwLockReadGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::MappedRwLockReadGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::nonpoison::MappedRwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::MappedRwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::nonpoison::RwLockReadGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::RwLockReadGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::nonpoison::RwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for sp_std::sync::RwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<A, B> Freeze for Chain<A, B>
where A: Freeze, B: Freeze,



impl<A, B> Freeze for Zip<A, B>
where A: Freeze, B: Freeze,



impl<A> Freeze for Repeat<A>
where A: Freeze,



impl<A> Freeze for RepeatN<A>
where A: Freeze,



impl<B, C> Freeze for ControlFlow<B, C>
where C: Freeze, B: Freeze,



impl<Dyn> Freeze for DynMetadata<Dyn>
where Dyn: ?Sized,



impl<F> Freeze for sp_std::fmt::FromFn<F>
where F: Freeze,



impl<F> Freeze for sp_std::iter::FromFn<F>
where F: Freeze,



impl<F> Freeze for OnceWith<F>
where F: Freeze,



impl<F> Freeze for RepeatWith<F>
where F: Freeze,



impl<G> Freeze for FromCoroutine<G>
where G: Freeze,



impl<H> Freeze for BuildHasherDefault<H>



impl<I, F, const N: usize> Freeze for MapWindows<I, F, N>
where F: Freeze, I: Freeze, <I as Iterator>::Item: Freeze,



impl<I, F> Freeze for FilterMap<I, F>
where I: Freeze, F: Freeze,



impl<I, F> Freeze for Inspect<I, F>
where I: Freeze, F: Freeze,



impl<I, F> Freeze for Map<I, F>
where I: Freeze, F: Freeze,



impl<I, G> Freeze for IntersperseWith<I, G>
where G: Freeze, I: Freeze, <I as Iterator>::Item: Freeze,



impl<I, P> Freeze for Filter<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for MapWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for SkipWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for TakeWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, St, F> Freeze for Scan<I, St, F>
where I: Freeze, F: Freeze, St: Freeze,



impl<I, U, F> Freeze for FlatMap<I, U, F>
where <U as IntoIterator>::IntoIter: Freeze, I: Freeze, F: Freeze,



impl<I, const N: usize> Freeze for ArrayChunks<I, N>
where I: Freeze, <I as Iterator>::Item: Freeze,



impl<I> Freeze for Cloned<I>
where I: Freeze,



impl<I> Freeze for Copied<I>
where I: Freeze,



impl<I> Freeze for Cycle<I>
where I: Freeze,



impl<I> Freeze for Enumerate<I>
where I: Freeze,



impl<I> Freeze for Flatten<I>
where <<I as Iterator>::Item as IntoIterator>::IntoIter: Freeze, I: Freeze,



impl<I> Freeze for Fuse<I>
where I: Freeze,



impl<I> Freeze for Intersperse<I>
where <I as Iterator>::Item: Sized + Freeze, I: Freeze,



impl<I> Freeze for Peekable<I>
where I: Freeze, <I as Iterator>::Item: Freeze,



impl<I> Freeze for Skip<I>
where I: Freeze,



impl<I> Freeze for StepBy<I>
where I: Freeze,



impl<I> Freeze for Take<I>
where I: Freeze,



impl<Idx> Freeze for sp_std::ops::Range<Idx>
where Idx: Freeze,



impl<Idx> Freeze for RangeFrom<Idx>
where Idx: Freeze,



impl<Idx> Freeze for RangeInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for RangeTo<Idx>
where Idx: Freeze,



impl<Idx> Freeze for RangeToInclusive<Idx>
where Idx: Freeze,



impl<K, V, A> Freeze for BTreeMap<K, V, A>
where A: Freeze,



impl<K, V, A> Freeze for sp_std::collections::btree_map::IntoIter<K, V, A>
where A: Freeze,



impl<K, V, A> Freeze for IntoKeys<K, V, A>
where A: Freeze,



impl<K, V, A> Freeze for IntoValues<K, V, A>
where A: Freeze,



impl<P> Freeze for MaybeDangling<P>
where P: Freeze + ?Sized,



impl<T, A> Freeze for Arc<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for BTreeSet<T, A>
where A: Freeze,



impl<T, A> Freeze for Box<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for sp_std::collections::btree_set::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for sp_std::collections::vec_deque::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for sp_std::vec::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for Rc<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for UniqueArc<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for UniqueRc<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for Vec<T, A>
where A: Freeze,



impl<T, A> Freeze for VecDeque<T, A>
where A: Freeze,



impl<T, A> Freeze for sp_std::rc::Weak<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for sp_std::sync::Weak<T, A>
where A: Freeze, T: ?Sized,



impl<T, E> Freeze for Result<T, E>
where T: Freeze, E: Freeze,



impl<T, F = fn() -> T> !Freeze for LazyCell<T, F>



impl<T, F = fn() -> T> !Freeze for LazyLock<T, F>



impl<T, F> Freeze for DropGuard<T, F>
where T: Freeze, F: Freeze,



impl<T, F> Freeze for Successors<T, F>
where F: Freeze, T: Freeze,



impl<T> !Freeze for Atomic<T>



impl<T> !Freeze for Cell<T>



impl<T> !Freeze for sp_std::sync::nonpoison::Mutex<T>



impl<T> !Freeze for sp_std::sync::Mutex<T>



impl<T> !Freeze for OnceCell<T>



impl<T> !Freeze for OnceLock<T>



impl<T> !Freeze for ReentrantLock<T>



impl<T> !Freeze for RefCell<T>



impl<T> !Freeze for sp_std::sync::nonpoison::RwLock<T>



impl<T> !Freeze for sp_std::sync::RwLock<T>



impl<T> !Freeze for SyncUnsafeCell<T>



impl<T> Freeze for Bound<T>
where T: Freeze,



impl<T> Freeze for Discriminant<T>



impl<T> Freeze for Empty<T>



impl<T> Freeze for sp_std::sync::mpmc::IntoIter<T>



impl<T> Freeze for sp_std::sync::mpsc::IntoIter<T>



impl<T> Freeze for sp_std::result::IntoIter<T>
where T: Freeze,



impl<T> Freeze for ManuallyDrop<T>
where T: Freeze + ?Sized,



impl<T> Freeze for MaybeUninit<T>
where T: Freeze,



impl<T> Freeze for NonNull<T>
where T: ?Sized,



impl<T> Freeze for sp_std::iter::Once<T>
where T: Freeze,



impl<T> Freeze for PhantomContravariant<T>
where T: ?Sized,



impl<T> Freeze for PhantomCovariant<T>
where T: ?Sized,



impl<T> Freeze for PhantomInvariant<T>
where T: ?Sized,



impl<T> Freeze for PoisonError<T>
where T: Freeze,



impl<T> Freeze for sp_std::sync::mpmc::Receiver<T>



impl<T> Freeze for sp_std::sync::mpsc::Receiver<T>



impl<T> Freeze for sp_std::sync::oneshot::Receiver<T>



impl<T> Freeze for sp_std::sync::oneshot::RecvTimeoutError<T>



impl<T> Freeze for Rev<T>
where T: Freeze,



impl<T> Freeze for Reverse<T>
where T: Freeze,



impl<T> Freeze for Saturating<T>
where T: Freeze,



impl<T> Freeze for SendError<T>
where T: Freeze,



impl<T> Freeze for SendTimeoutError<T>
where T: Freeze,



impl<T> Freeze for sp_std::sync::mpmc::Sender<T>



impl<T> Freeze for sp_std::sync::mpsc::Sender<T>



impl<T> Freeze for sp_std::sync::oneshot::Sender<T>



impl<T> Freeze for SyncSender<T>



impl<T> Freeze for SyncView<T>
where T: Freeze + ?Sized,



impl<T> Freeze for ThinBox<T>
where T: ?Sized,



impl<T> Freeze for TraitImpl<T>
where T: ?Sized,



impl<T> Freeze for TryLockError<T>
where T: Freeze,



impl<T> Freeze for sp_std::sync::oneshot::TryRecvError<T>



impl<T> Freeze for TrySendError<T>
where T: Freeze,



impl<T> Freeze for Wrapping<T>
where T: Freeze,



impl<T> Freeze for Yeet<T>
where T: Freeze,



impl<Y, R> Freeze for CoroutineState<Y, R>
where Y: Freeze, R: Freeze,